@@ -37,6 +37,8 @@ def debug_option(f):
     def callback(ctx, param, debug):
         if debug:
             logging.getLogger().setLevel(logging.DEBUG)
+            for handle in logging.getLogger().handlers:
+                handle.setLevel(logging.DEBUG)
 
         return debug
 
@@ -181,9 +183,13 @@ def cli_status(**kwargs):
 
 
 @cli.command('plot')
-@click.option('-x', 'x_val', type=str, help='IDS of the x value')
+@click.option('-x',
+              'x_path',
+              default='profiles_1d/$time/grid/rho_tor_norm',
+              type=str,
+              help='IDS of the x value')
 @click.option('-y',
-              'y_vals',
+              'y_paths',
               type=str,
               help='IDS of the y value',
               multiple=True)
@@ -193,12 +199,24 @@ def cli_status(**kwargs):
               type=str,
               help='IMAS path formatted as <user>/<db>/<shot>/<number>.',
               multiple=True)
+@click.option('-d',
+              '--ids',
+              type=str,
+              default='core_profiles',
+              help='Which IDS to grab data from')
 @click.option('-i',
               '--input',
               'input_files',
               type=str,
               help='Input file, i.e. `data.csv` or `runs.yaml`',
               multiple=True)
+@click.option('-o',
+              '--format',
+              'extensions',
+              type=str,
+              help='Output format (json, html, png, svg, pdf), default: html.',
+              default=('html', ),
+              multiple=True)
 @common_options
 def cli_plot(**kwargs):
     """Plot some IDS data."""
@@ -256,7 +274,8 @@ def cli_dash(**kwargs):
 def cli_merge(**kwargs):
     """Merge data sets with error propagation."""
     from .merge import merge
-    merge(**kwargs)
+    with op_queue_context():
+        merge(**kwargs)
 
 
 if __name__ == '__main__':
