@@ -1,6 +1,8 @@
 import logging
 from typing import Iterable
 
+import pandas as pd
+
 from duqtools.config import cfg
 
 from .ids import ImasHandle, apply_model
@@ -28,25 +30,30 @@ def fail_if_locations_exist(locations: Iterable[ImasHandle]):
             'remove or `--force` to override.')
 
 
-@add_to_op_queue('Setting inital condition of', '{target_in}')
+@add_to_op_queue('Setting inital condition of', '{target_in}', quiet=True)
 def apply_combination(target_in: ImasHandle, combination) -> None:
-    ids_mapping = target_in.get('core_profiles')
-
     for model in combination:
+        ids_mapping = target_in.get(model.variable.ids)
         apply_model(model, ids_mapping)
 
         logger.info('Writing data entry: %s', target_in)
         ids_mapping.sync(target_in)
 
 
-@add_to_op_queue('Writing out', '{workspace.runs_yaml}')
+@add_to_op_queue('Writing runs', '{workspace.runs_yaml}', quiet=True)
 def write_runs_file(runs: list, workspace) -> None:
-
     runs = Runs.parse_obj(runs)
     with open(workspace.runs_yaml, 'w') as f:
         runs.yaml(stream=f)
 
 
+@add_to_op_queue('Writing csv', quiet=True)
+def write_runs_csv(runs, fname: str = 'data.csv'):
+    run_map = {run['dirname']: run['data_out'].dict() for run in runs}
+    df = pd.DataFrame.from_dict(run_map, orient='index')
+    df.to_csv(fname)
+
+
 def create(*, force, **kwargs):
     """Create input for jetto and IDS data structures.
 
@@ -58,6 +65,7 @@ def create(*, force, **kwargs):
         Unused.
     """
     options = cfg.create
+
     if not options:
         logger.warning('No create options specified.')
         return
@@ -77,7 +85,7 @@ def create(*, force, **kwargs):
 
     logger.info('Source data: %s', source)
 
-    matrix = tuple(dim.expand() for dim in dimensions)
+    matrix = tuple(model.expand() for model in dimensions)
     combinations = matrix_sampler(*matrix, **dict(options.sampler))
 
     if not force:
@@ -86,7 +94,7 @@ def create(*, force, **kwargs):
                 'Directory is not empty, use `duqtools clean` to clear or '
                 '`--force` to override.')
 
-        locations = (ImasHandle(db=options.data.db,
+        locations = (ImasHandle(db=options.data.imasdb,
                                 shot=source.shot,
                                 run=options.data.run_in_start_at + i)
                      for i in range(len(combinations)))
@@ -104,13 +112,13 @@ def create(*, force, **kwargs):
                          'parents': True,
                          'exist_ok': force
                      },
-                     description='Create folder',
+                     description='Creating run',
                      extra_description=f'{run_drc}')
 
-        target_in = ImasHandle(db=options.data.db,
+        target_in = ImasHandle(db=options.data.imasdb,
                                shot=source.shot,
                                run=options.data.run_in_start_at + i)
-        target_out = ImasHandle(db=options.data.db,
+        target_out = ImasHandle(db=options.data.imasdb,
                                 shot=source.shot,
                                 run=options.data.run_out_start_at + i)
 
@@ -119,7 +127,7 @@ def create(*, force, **kwargs):
         apply_combination(target_in, combination)
 
         system.copy_from_template(template_drc, run_drc)
-        system.write_batchfile(workspace, run_name)
+        system.write_batchfile(workspace, run_name, template_drc)
 
         system.update_imas_locations(run=run_drc,
                                      inp=target_in,
@@ -133,3 +141,4 @@ def create(*, force, **kwargs):
         })
 
     write_runs_file(runs, workspace)
+    write_runs_csv(runs)
