@@ -5,7 +5,8 @@ from ._handle import ImasHandle
 from ._io import get_ids_dataframe
 from ._mapping import IDSMapping
 from ._merge import merge_data
-from ._rebase import rebase_on_grid, rebase_on_time
+from ._rebase import rebase_on_grid, rebase_on_time, standardize_grid
+from ._variable import Variable
 
 logger = logging.getLogger(__name__)
 
@@ -17,4 +18,6 @@ __all__ = [
     'merge_data',
     'rebase_on_grid',
     'rebase_on_time',
+    'standardize_grid',
+    'Variable',
 ]
