@@ -104,7 +104,10 @@ class ImasHandle(ImasBaseModel):
             Copy data to a new location.
         """
         logger.debug('Copy %s to %s', self, destination)
-        copy_ids_entry(self, destination)
+        try:
+            copy_ids_entry(self, destination)
+        except Exception as err:
+            raise IOError(f'Failed to copy {self}') from err
 
     @add_to_op_queue('Removing ids', '{self}')
     def delete(self):
@@ -120,12 +123,12 @@ class ImasHandle(ImasBaseModel):
             except FileNotFoundError:
                 logger.warning('%s does not exist', to_delete)
 
-    def get_raw_data(self, key: str = 'core_profiles', **kwargs):
+    def get_raw_data(self, ids: str = 'core_profiles', **kwargs):
         """Get data from IDS entry.
 
         Parameters
         ----------
-        key : str, optional
+        ids : str, optional
             Name of profiles to open.
         **kwargs
             These keyword parameters are passed to `ImasHandle.open()`.
@@ -135,19 +138,19 @@ class ImasHandle(ImasBaseModel):
         data
         """
         with self.open(**kwargs) as data_entry:
-            data = data_entry.get(key)
+            data = data_entry.get(ids)
 
         # reset string representation because output is extremely lengthy
         _patch_str_repr(data)
 
         return data
 
-    def get(self, key: str = 'core_profiles', **kwargs) -> IDSMapping:
+    def get(self, ids: str = 'core_profiles', **kwargs) -> IDSMapping:
         """Map the data to a dict-like structure.
 
         Parameters
         ----------
-        key : str, optional
+        ids : str, optional
             Name of profiles to open
         **kwargs
             These parameters are passed to initialize `IDSMapping`.
@@ -156,7 +159,7 @@ class ImasHandle(ImasBaseModel):
         -------
         IDSMapping
         """
-        raw_data = self.get_raw_data(key)
+        raw_data = self.get_raw_data(ids)
         return IDSMapping(raw_data, **kwargs)
 
     def entry(self, backend=imasdef.MDSPLUS_BACKEND):
