@@ -3,18 +3,25 @@ from __future__ import annotations
 import re
 from collections import defaultdict
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Any, Dict, Sequence, Set, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Sequence, Set, Tuple, Union
 
 import numpy as np
 
+from ..schema import VariableModel
 from ._constants import TIME_COL, TSTEP_COL
 from ._copy import add_provenance_info
+from ._variable import Variable
 
 if TYPE_CHECKING:
     import pandas as pd
+    import xarray as xr
 
     from ._handle import ImasHandle
 
+TIME_STR = '$time'
+
+DIM_PATTERN = re.compile(r'(?P<index>\$(?P<dim>\w+))\/')
+
 
 def insert_re_caret_dollar(string: str) -> str:
     """Insert regex start (^) / end ($) of line matching characters."""
@@ -25,27 +32,26 @@ def insert_re_caret_dollar(string: str) -> str:
     return string
 
 
+def replace_time_str(string: str) -> str:
+    """Replaces template string with regex digit matching."""
+    return string.replace(TIME_STR, r'(?P<idx>\d+)')
+
+
 class IDSMapping(Mapping):
 
-    def __init__(self,
-                 ids,
-                 exclude_empty: bool = True,
-                 allow_blind_keys: bool = False):
+    def __init__(self, ids, exclude_empty: bool = True):
         """__init__
 
         Parameters
         ----------
         ids :
-            ids
+            IMAS DB entry for the IDS.
         exclude_empty : bool
-            exclude_empty
-        allow_blind_keys : bool
-            allows for the getting and inserting of keys which are not in the _keys,
-            but could still fit in the ids
+            Hide empty arrays from mapping. You can still get/set these keys directly,
+            but `key in map` returns `False` if `map['key']` is an empty array.
         """
         self._ids = ids
         self.exclude_empty = exclude_empty
-        self.allow_blind_keys = allow_blind_keys
 
         # All available data fields are stored in this set.
         self._keys: Set[str] = set()
@@ -78,24 +84,28 @@ class IDSMapping(Mapping):
         return pointer, attr
 
     def __getitem__(self, key: str):
-        if (key not in self._keys) and not self.allow_blind_keys:
-            raise KeyError(key)
 
         try:
             pointer, attr = self._deconstruct_key(key)
             ret = getattr(pointer, attr)
-        except AttributeError as ea:
-            raise KeyError(str(ea))
+        except AttributeError as err:
+            raise KeyError(key) from err
+        except IndexError as err:
+            raise KeyError(key) from err
 
         return ret
 
     def __setitem__(self, key: str, value: np.ndarray):
-        if (key not in self._keys) and not self.allow_blind_keys:
-            raise KeyError(f'Cannot set non-existant key: {key}')
 
-        pointer, attr = self._deconstruct_key(key)
-
-        setattr(pointer, attr, value)
+        try:
+            pointer, attr = self._deconstruct_key(key)
+            getattr(pointer, attr)
+        except AttributeError as err:
+            raise KeyError(key) from err
+        except IndexError as err:
+            raise KeyError(key) from err
+        else:
+            setattr(pointer, attr, value)
 
     def __iter__(self):
         yield from self._keys
@@ -103,6 +113,63 @@ class IDSMapping(Mapping):
     def __len__(self):
         return len(self._keys)
 
+    def __contains__(self, key):
+        return key in self._keys
+
+    def get_with_replace(self, variable: Union[str, VariableModel],
+                         **kwargs) -> Any:
+        """Grab key with placeholder replacement.
+
+        Example: `IDSMapping.get_with_replace(var, time=0)`
+        """
+        path = variable.path if isinstance(variable,
+                                           VariableModel) else variable
+
+        for old, new in kwargs.items():
+            path = path.replace(f'${old}', str(new))
+
+        return self[path]
+
+    def set_with_replace(self, variable: Union[str, VariableModel], value: Any,
+                         **kwargs):
+        """Grab key with placeholder replacement.
+
+        Example: `IDSMapping.set_with_replace(var, value, time=0)`
+        """
+        path = variable.path if isinstance(variable,
+                                           VariableModel) else variable
+
+        for old, new in kwargs.items():
+            path = path.replace(f'${old}', str(new))
+
+        self[path] = value
+
+    def length_of_key(self, key: str):
+        """length_of_key gives you the number of entries of a (partial) ids
+        path, or None if the length does not exist.
+
+        Note: this is different then the length of an IDSMapping, which is defined
+        as the number of keys
+
+        Note: calling `len(map[key])` works as well
+
+        ## Example:
+
+
+        ```python
+        map.length_of_key('1d_profiles')
+        ```
+
+        Parameters
+        ----------
+        key : str
+            key
+        """
+        try:
+            return len(self[key])
+        except Exception:
+            pass
+
     def sync(self, target: ImasHandle):
         """Synchronize updated data back to IMAS db entry.
 
@@ -114,7 +181,7 @@ class IDSMapping(Mapping):
             Points to an IMAS db entry of where the data should be written.
         """
 
-        add_provenance_info(target)
+        add_provenance_info(handle=target)
 
         with target.open() as db_entry:
             self._ids.put(db_entry=db_entry)
@@ -176,6 +243,7 @@ class IDSMapping(Mapping):
             New dict with all matching key/value pairs.
         """
         pattern = insert_re_caret_dollar(pattern)
+        pattern = replace_time_str(pattern)
 
         pat = re.compile(pattern)
 
@@ -198,6 +266,7 @@ class IDSMapping(Mapping):
             New dict with all matching key/value pairs.
         """
         pattern = insert_re_caret_dollar(pattern)
+        pattern = replace_time_str(pattern)
 
         pat = re.compile(pattern)
 
@@ -214,10 +283,10 @@ class IDSMapping(Mapping):
     def find_by_index(self, pattern: str) -> Dict[str, Dict[int, np.ndarray]]:
         """Find keys matching regex pattern using time index.
 
-        Must include $i, which is a special character that matches
-        an integer (`\\d+`)
+        Must include $time, which is a special character that matches
+        an integer time step (`\\d+`)
 
-        i.e. `ids.find_by_index('profiles_1d/$i/zeff.*')`
+        i.e. `ids.find_by_index('profiles_1d/$time/zeff.*')`
         returns a dict with `zeff` and error attributes.
 
         Parameters
@@ -230,14 +299,13 @@ class IDSMapping(Mapping):
         dict
             New dict with all matching key/value pairs.
         """
-        idx_str = '$i'
-
-        if idx_str not in pattern:
-            raise ValueError(f'Pattern must include {idx_str} to match index.')
+        if TIME_STR not in pattern:
+            raise ValueError(
+                f'Pattern must include ../{TIME_STR}/.. to match index.')
 
         pattern = insert_re_caret_dollar(pattern)
+        pattern = replace_time_str(pattern)
 
-        pattern = pattern.replace(idx_str, r'(?P<idx>\d+)')
         pat = re.compile(pattern)
 
         new_dict: Dict[str, Dict[int, np.ndarray]] = defaultdict(dict)
@@ -247,7 +315,7 @@ class IDSMapping(Mapping):
 
             if m:
                 si, sj = m.span('idx')
-                new_key = key[:si] + idx_str + key[sj:]
+                new_key = key[:si] + TIME_STR + key[sj:]
 
                 idx = int(m.group('idx'))
                 new_dict[new_key][idx] = self[key]
@@ -288,6 +356,52 @@ class IDSMapping(Mapping):
 
         return df
 
+    def to_xarray(
+        self,
+        variables: Sequence[Variable],
+        **kwargs,
+    ) -> xr.Dataset:
+        """Return dataset for given variables.
+
+        Parameters
+        ----------
+        variables : Dict[str, Variable]
+            Dictionary of data variables
+
+        Returns
+        -------
+        ds : xr.Dataset
+            Return query as Dataset
+        """
+        import xarray as xr
+
+        xr_data_vars: Dict[str, Tuple[List[str], np.array]] = {}
+
+        for var in variables:
+            dimensions = DIM_PATTERN.findall(var.path)
+
+            if not dimensions:
+                xr_data_vars[var.name] = (var.dims, self[var.path])
+                continue
+
+            if len(dimensions) > 1:
+                raise NotImplementedError
+
+            index_string, dimension = dimensions[0]
+            prefix = var.path.split(index_string)[0].strip('/')
+
+            arr = []
+
+            for index in range(len(self[prefix])):
+                path = var.path.replace(index_string, str(index))
+                arr.append(self[path])
+
+            xr_data_vars[var.name] = ([dimension, *var.dims], arr)
+
+        ds = xr.Dataset(data_vars=xr_data_vars, )
+
+        return ds
+
     def to_numpy(
         self,
         *variables: str,
