@@ -9,7 +9,8 @@ from typing_extensions import Literal
 from ..models import AbstractSystem
 from ..operations import add_to_op_queue
 from ._imas_functions import imas_from_jset_input
-from ._jset import JettoSettings
+from ._jetto_jset import JettoJset
+from ._settings_manager import JettoSettingsManager
 
 if TYPE_CHECKING:
     from ..ids import ImasHandle
@@ -29,13 +30,16 @@ class JettoSystem(AbstractSystem):
     name: Literal['jetto'] = Field('jetto', description='Name of the system.')
 
     @staticmethod
-    @add_to_op_queue('Writing new batchfile', '{run_name}')
-    def write_batchfile(workspace: WorkDirectory, run_name: str):
+    @add_to_op_queue('Writing new batchfile', '{run_name}', quiet=True)
+    def write_batchfile(workspace: WorkDirectory, run_name: str,
+                        template_drc: Path):
         from duqtools.jetto import write_batchfile as jetto_write_batchfile
-        return jetto_write_batchfile(workspace, run_name)
+        jset = JettoJset.from_directory(template_drc)
+
+        return jetto_write_batchfile(workspace, run_name, jset)
 
     @staticmethod
-    @add_to_op_queue('Copying template to', '{target_drc}')
+    @add_to_op_queue('Copying template to', '{target_drc}', quiet=True)
     def copy_from_template(source_drc: Path, target_drc: Path):
         from duqtools.jetto import copy_files
         return copy_files(source_drc, target_drc)
@@ -43,14 +47,15 @@ class JettoSystem(AbstractSystem):
     @staticmethod
     def imas_from_path(template_drc: Path):
 
-        jset = JettoSettings.from_directory(template_drc)
-        source = imas_from_jset_input(jset)
+        jetto_settings = JettoSettingsManager.from_directory(template_drc)
+        source = imas_from_jset_input(jetto_settings)
         assert source.path().exists()
         return source
 
     @staticmethod
-    @add_to_op_queue('Updating imas locations of', '{run}')
+    @add_to_op_queue('Updating imas locations of', '{run}', quiet=True)
     def update_imas_locations(run: Path, inp: ImasHandle, out: ImasHandle):
-        jset = JettoSettings.from_directory(run)
-        jset_copy = jset.set_imas_locations(inp=inp, out=out)
-        jset_copy.to_directory(run)
+        jetto_settings = JettoSettingsManager.from_directory(run)
+        jetto_settings_copy = jetto_settings.set_imas_locations(inp=inp,
+                                                                out=out)
+        jetto_settings_copy.to_directory(run)
