@@ -18,7 +18,8 @@ class AbstractSystem(ABC, BaseModel):
 
     @staticmethod
     @abstractmethod
-    def write_batchfile(workspace: WorkDirectory, run_name: str):
+    def write_batchfile(workspace: WorkDirectory, run_name: str,
+                        template_drc: Path):
         pass
 
     @staticmethod
