@@ -22,6 +22,8 @@ class Operation(BaseModel):
     following members:
     """
 
+    quiet: bool = Field(False,
+                        description='print out this operation to the screen')
     description: str = Field(
         description='description of the operation to be done')
     action: Callable = Field(
@@ -154,10 +156,11 @@ class Operations(deque):
             with tqdm(iterable=False, bar_format='{desc}', position=0) as dbar:
                 while len(self) != 0:
                     op = self.popleft()
-                    op()
-                    dbar.set_description(op.description)
+                    if not op.quiet:
+                        dbar.set_description(op.description)
                     logger.info(op.description)
                     pbar.update()
+                    op()
 
     def confirm_apply_all(self) -> bool:
         """First asks the user if he wants to apply everything.
@@ -173,7 +176,8 @@ class Operations(deque):
             click.style('Operations in the Queue:', fg='red', bold=True))
         self.logger.info(click.style('========================', fg='red'))
         for op in self:
-            self.logger.info('- ' + op.description)
+            if not op.quiet:
+                self.logger.info('- ' + op.description)
 
         if self.dry_run:
             self.logger.info('Dry run enabled, not applying op_queue')
@@ -188,22 +192,13 @@ class Operations(deque):
 
     def check_unconfirmed_operations(self):
         """Safety check, it should never happen that operations are not
-        executed.
-
-        , check it anyway at program exit
-        """
+        executed."""
         if len(self) != 0:
             self.logger.warning(
-                click.style(
-                    'There are unconfirmed operations in the queue at program exit!',
-                    fg='yellow',
-                    bold=True))
-            for op in self:
-                self.logger.warning('- ' + op.description)
-            self.logger.warning(
-                click.style(
-                    'Did you forget to use the @confirm_operations decorator?',
-                    fg='yellow'))
+                click.style((f'There are still {len(self)} operations '
+                             'in the queue at program exit!'),
+                            fg='red',
+                            bold=True))
 
 
 op_queue = Operations()
@@ -228,17 +223,24 @@ def confirm_operations(func):
     def wrapper(*args, **kwargs):
         if op_queue.enabled:
             raise RuntimeError('op_queue already enabled')
-        op_queue.enabled = True
-        ret = func(*args, **kwargs)
-        op_queue.confirm_apply_all()
-        op_queue.clear()
-        op_queue.enabled = False
+        try:
+            op_queue.enabled = True
+            ret = func(*args, **kwargs)
+            op_queue.confirm_apply_all()
+            op_queue.clear()
+            op_queue.enabled = False
+        except Exception:
+            op_queue.clear()
+            op_queue.enabled = False
+            raise
         return ret
 
-    return wrapper
+        return wrapper
 
 
-def add_to_op_queue(op_desc: str, extra_desc: Optional[str] = None):
+def add_to_op_queue(op_desc: str,
+                    extra_desc: Optional[str] = None,
+                    quiet=False):
     """Decorator which adds the function call to the op_queue, instead of
     executing it directly, the string can be a format string and use the
     function arguments.
@@ -275,7 +277,8 @@ def add_to_op_queue(op_desc: str, extra_desc: Optional[str] = None):
                          args=args,
                          kwargs=kwargs,
                          description=op_formatted,
-                         extra_description=extra_formatted)
+                         extra_description=extra_formatted,
+                         quiet=quiet)
 
         return wrapper
 
@@ -295,8 +298,13 @@ def op_queue_context():
 
     if op_queue.enabled:
         raise RuntimeError('op_queue already enabled')
-    op_queue.enabled = True
-    yield
-    op_queue.confirm_apply_all()
-    op_queue.clear()
-    op_queue.enabled = False
+    try:
+        op_queue.enabled = True
+        yield
+        op_queue.confirm_apply_all()
+        op_queue.clear()
+        op_queue.enabled = False
+    except Exception:
+        op_queue.clear()
+        op_queue.enabled = False
+        raise
