@@ -1,29 +1,58 @@
 from getpass import getuser
-from typing import List, Union
+from pathlib import Path
+from typing import Dict, List, Union
 
-from pydantic import DirectoryPath, Field, validator
+from pydantic import DirectoryPath, Field, root_validator
 from typing_extensions import Literal
 
 from ._basemodel import BaseModel
 from ._description_helpers import formatter as f
 from ._dimensions import IDSOperationDim
 from ._imas import ImasBaseModel
+from ._variable import VariableModel
 from .data_location import DataLocation
 from .matrix_samplers import (CartesianProduct, HaltonSampler, LHSSampler,
                               SobolSampler)
 from .workdir import WorkDirectoryModel
 
 
-class DeprecatedValueError(ValueError):
-    ...
+class VariableConfigModel(BaseModel):
+    __root__: List[VariableModel] = Field([
+        VariableModel(name='rho_tor_norm',
+                      ids='core_profiles',
+                      path='profiles_1d/$time/grid/rho_tor_norm',
+                      dims=['x']),
+        VariableModel(name='t_i_average',
+                      ids='core_profiles',
+                      path='profiles_1d/$time/t_i_average',
+                      dims=['x']),
+        VariableModel(name='zeff',
+                      ids='core_profiles',
+                      path='profiles_1d/$time/zeff',
+                      dims=['x']),
+        VariableModel(name='time',
+                      ids='core_profiles',
+                      path='time',
+                      dims=['time']),
+    ])
+
+    def __iter__(self):
+        yield from self.__root__
+
+    def __getitem__(self, index: int):
+        return self.__root__[index]
+
+    def to_variable_dict(self) -> dict:
+        """Return dict of variables."""
+        return {variable.name: variable for variable in self}
 
 
 class CreateConfigModel(BaseModel):
     """The options of the `create` subcommand are stored in the `create` key in
     the config."""
     dimensions: List[Union[IDSOperationDim]] = Field([
-        IDSOperationDim(ids='profiles_1d/0/t_i_average', ),
-        IDSOperationDim(ids='profiles_1d/0/electrons/temperature')
+        IDSOperationDim(variable='t_i_average'),
+        IDSOperationDim(variable='zeff')
     ],
                                                      description=f("""
         The `dimensions` specifies the dimensions of the matrix to sample
@@ -35,11 +64,6 @@ class CreateConfigModel(BaseModel):
         this hypercube can be efficiently sampled.
         """))
 
-    matrix: List = Field(None,
-                         deprecated=True,
-                         description='Use `dimensions` instead.',
-                         exclude=True)
-
     sampler: Union[LHSSampler, HaltonSampler, SobolSampler,
                    CartesianProduct] = Field(default=LHSSampler(),
                                              discriminator='method',
@@ -76,18 +100,12 @@ class CreateConfigModel(BaseModel):
                                description=f("""
         Where to store the in/output IDS data.
         The data key specifies the machine or imas
-        `db` name where to store the data (`db`). duqtools will write the input
+        database name where to store the data (`imasdb`). duqtools will write the input
         data files for UQ start with the run number given by `run_in_start_at`.
         The data generated by the UQ runs (e.g. from jetto) will be stored
         starting by the run number given by `run_out_start_at`.
         """))
 
-    @validator('matrix', always=True, pre=True)
-    def deprecate_matrix(v):
-        if v:
-            raise DeprecatedValueError(
-                "'matrix' has been deprecated, use 'dimensions' instead.")
-
 
 class SubmitConfigModel(BaseModel):
     """The options of the `submit` subcommand are stored under the `submit` key
@@ -141,14 +159,66 @@ class StatusConfigModel(BaseModel):
             """))
 
 
+class MergeStep(BaseModel):
+    """These parameters describe which paths should be merged.
+
+    Three sets of variables need to be defined:
+    - time_variable: this points to the data for the time coordinate
+    - grid_variable: this points to the data for the grid variable
+    - data_variables: these point to the data to be merged
+
+    Note that all variables must be from the same IDS.
+
+    The grid and data variables must share a common dimension. The grid variable
+    will be used to rebase all data variables to a common grid.
+
+    The time variable will be used to rebase the grid variable and the data variables
+    to a common time coordinate. To denote the time index, use `/$time/` in both
+    the grid and data variables.
+
+    Rebasing involves interpolation.
+
+    Note that multiple merge steps can be specified, for example for different
+    IDS.
+    """
+    data_variables: List[Union[str,
+                               VariableModel]] = Field(['t_i_average', 'zeff'],
+                                                       description=f("""
+            This is a list of data variables to be merged. This means
+            that the mean and error for these data over all runs are calculated
+            and written back to the ouput data location.
+            The paths should contain `/$time/` for the time component.
+            """))
+    grid_variable: Union[str, VariableModel] = Field('rho_tor_norm',
+                                                     description=f("""
+            This variable points to the data for the grid coordinate. It must share a common
+            placeholder dimension with the data variables.
+            It will be used to rebase all data variables to same (radial) grid before merging
+            using interpolation.
+            The path should contain '/$time/' to denote the time component.
+            """))
+    time_variable: Union[str, VariableModel] = Field('time',
+                                                     description=f("""
+            This variable determines the time coordinate to merge on. This ensures
+            that the data from all runs are on the same time coordinates before
+            merging.
+            """))
+
+
 class MergeConfigModel(BaseModel):
     """The options of the `merge` subcommand are stored under the `merge` key
     in the config.
 
-    These keys define which data to merge, and where to store the
-    output. Before merging, all keys are rebased on (1) the same radial
+    These keys define the location of the IMAS data, which IDS entries
+    to merge, and where to store the output.
+
+    Before merging, all keys are rebased on (1) the same radial
     coordinate specified via `base_ids` and (2) the timestamp.
     """
+    data: Path = Field('runs.yaml',
+                       description=f("""
+            Data file with IMAS handles, such as `data.csv` or `runs.yaml`'
+            """))
     template: ImasBaseModel = Field(
         {
             'user': getuser(),
@@ -156,7 +226,10 @@ class MergeConfigModel(BaseModel):
             'shot': 94785,
             'run': 1
         },
-        description='This IMAS DB entry will be used as the template.')
+        description=f("""
+            This IMAS DB entry will be used as the template.
+            It is copied to the output location.
+            """))
     output: ImasBaseModel = Field(
         {
             'db': 'jet',
@@ -164,21 +237,8 @@ class MergeConfigModel(BaseModel):
             'run': 9999
         },
         description='Merged data will be written to this IMAS DB entry.')
-    ids_to_merge: List[str] = Field(['t_i_average', 'zeff'],
-                                    description=f("""
-            This is a list of IDSs to merge over all runs together with the `prefix`.
-            The mean/error are written to the target IDS.
-        """))
-    base_ids: str = Field('grid/rho_tor_norm',
-                          description=f("""
-            This IDS field is taken from the template. It is used to rebase all IDS fields
-            to same radial grid before merging using an interpolation.
-            """))
-    prefix: str = Field('profiles_1d',
-                        description=f("""
-            This field specifies the prefix to the IDS path, i.e.
-            `<prefix>/<time_step>/<ids_to_merge>'. The time step is implied by the template.
-            """))
+    plan: List[MergeStep] = Field([MergeStep()],
+                                  description='List of merging operations.')
 
 
 class ConfigModel(BaseModel):
@@ -201,14 +261,45 @@ class ConfigModel(BaseModel):
         MergeConfigModel(),
         description='Configuration for the merge subcommand')
 
+    variables: VariableConfigModel = Field(
+        VariableConfigModel(),
+        description='Define variables for use in the subcommands.')
+
     workspace: WorkDirectoryModel = WorkDirectoryModel()
     system: Literal['jetto',
                     'dummy'] = Field('jetto',
                                      description='backend system to use')
 
-    @validator('plot', always=True, pre=True)
-    def deprecate_matrix(v):
-        if v:
-            raise DeprecatedValueError(
-                "'plot' config has been deprecated, you can remove this "
-                'section from your config file.')
+    @root_validator(pre=False, skip_on_failure=True)
+    def update_variables(cls, values):
+        """Grab variable names from different steps and replace them with the
+        definitions from the `variables` attribute."""
+        var_dict = values['variables'].to_variable_dict()
+
+        def validate_variable(var: Union[str, VariableModel],
+                              dct: Dict[str, VariableModel]) -> VariableModel:
+            if isinstance(var, VariableModel):
+                return var
+
+            try:
+                variable_model = dct[var]
+            except KeyError:
+                raise KeyError(f'Variable: `{var}` has not been defined.')
+
+            return variable_model
+
+        for dimension in values['create'].dimensions:
+            dimension.variable = validate_variable(dimension.variable,
+                                                   var_dict)
+
+        for step in values['merge'].plan:
+            step.grid_variable = validate_variable(step.grid_variable,
+                                                   var_dict)
+            step.time_variable = validate_variable(step.time_variable,
+                                                   var_dict)
+            step.data_variables = [
+                validate_variable(variable, var_dict)
+                for variable in step.data_variables
+            ]
+
+        return values
